@@ -8,6 +8,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 import pydantic
 from libwebid.canon import IdentityDocument
+from libwebid.canon import IdentityClaimAggregate
 from libwebid.lib.i18n import gettext as _
 
 
@@ -40,9 +41,15 @@ class RetrieveSessionResponse(pydantic.BaseModel):
 
     document: IdentityDocument | None = pydantic.Field(
         default=None,
-        title="Document",
+        title=_("Document"),
         description=_(
             "The identity document submitted to the session. Only present "
             "if `status` is `success`, otherwise `document` is `null`."
         )
+    )
+
+    aggregated: IdentityClaimAggregate | None = pydantic.Field(
+        default=None,
+        title=_("Aggregated claims"),
+        description=_("The aggregated claims of the identity.")
     )
\ No newline at end of file
