@@ -6,9 +6,12 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+from typing import Any
+
 import pydantic
 
 from .oauthclientdto import OAuthClientDTO
+from .sessionclaims import SessionClaims
 
 
 class AuthorizationRequestDTO(pydantic.BaseModel):
@@ -20,6 +23,16 @@ class AuthorizationRequestDTO(pydantic.BaseModel):
     requests: list[str]
     acr_values: list[str] = []
     amr_values: list[str] = []
+    authorized_domains: list[str] = []
+    tasks: list[Any] = []
+    session: dict[str, Any] = {}
+
+    def is_authorized_email(self, session: SessionClaims) -> bool:
+        email = self.session.get('email') or session.email
+        if email is None:
+            return False
+        _, domain = str.split(email, '@')
+        return domain in self.authorized_domains
 
     def wants_amr(self, amr: str | set[str]) -> bool:
         """Return a boolean indicating if the request wants the given
