@@ -19,7 +19,7 @@ class ConflictingClaim(pydantic.BaseModel):
         description=_("The claim that caused a conflict.")
     )
 
-    conflicts: list[IdentityClaimType] = pydantic.Field(
+    conflicts: dict[str, IdentityClaimType] = pydantic.Field(
         default=...,
         title=_("Conflict"),
         description=_("The list of claims that are conflicted with.")
