@@ -14,10 +14,11 @@ from .genderidentityclaim import GenderIdentityClaim
 from .stringidentityclaim import StringIdentityClaim
 from .officialgivennamesclaim import OfficialGivenNameIdentityClaim
 from .nameidentityclaim import NameIdentityClaim
+from .ncnidentityclaim import NCNIdentityClaim
 
 
 IdentityClaimType: TypeAlias = (
-    GenderIdentityClaim | BirthplaceIdentityClaim |
+    GenderIdentityClaim | BirthplaceIdentityClaim | NCNIdentityClaim |
     OfficialGivenNameIdentityClaim | NameIdentityClaim |
     DateIdentityClaim | StringIdentityClaim
 )
\ No newline at end of file
