@@ -19,7 +19,11 @@ class DocumentServiceRepository(ServiceRepository):
         session_id: int,
         with_pii: bool = False
     ) -> documents.RetrieveSessionResponse | None:
+        params: dict[str, str] = {}
+        if with_pii:
+            params['pii'] = 'true'
         return await self.retrieve(
             resource_path=f'sessions/{session_id}',
-            response_model=documents.RetrieveSessionResponse
+            response_model=documents.RetrieveSessionResponse,
+            params=params
         )
\ No newline at end of file
