@@ -7,10 +7,12 @@
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 from .email import EmailService
+from .email import NullEmailService
 from .fingerprint import FingerprintService
 
 
 __all__: list[str] = [
     'EmailService',
     'FingerprintService',
+    'NullEmailService',
 ]
\ No newline at end of file
