@@ -139,17 +139,19 @@ class GoogleDatastoreRepository(ddd.Repository):
             break
         return result
 
-    async def persist_model(self, obj: T) -> T:
-        entity = self.entity_factory(id=getattr(obj, self.id_attr))
+    async def persist_model(self, obj: T, kind: str | None = None) -> T:
+        entity = self.entity_factory(id=getattr(obj, self.id_attr), kind=kind)
         entity.update(obj.dict(exclude=self.exclude | {self.id_attr})) # type: ignore
         await self.put(entity)
-        setattr(obj, self.id_attr, entity.key.id) # type: ignore
-        return obj
+        return self.model.parse_obj({ # type: ignore
+            **entity,
+            self.id_attr: entity.key.id # type: ignore
+        })
 
     async def put(self, entity: Entity) -> Entity:
         await self.run_in_executor(self.client.put, entity) # type: ignore
         assert (entity.key.id or entity.key.name) is not None # type: ignore # nosec
         return entity
 
-    def query(self, kind: str | None = None) -> Query:
-        return self.client.query(kind=kind or self.kind) # type: ignore
\ No newline at end of file
+    def query(self, kind: str | None = None, ancestor: Key | None = None) -> Query:
+        return self.client.query(kind=kind or self.kind, ancestor=ancestor) # type: ignore
\ No newline at end of file
