@@ -24,6 +24,9 @@ class StorageEncrypter:
     def __init__(self, svc: ServiceClient = CurrentService) -> None:
         self._client = svc
 
+    async def index(self, value: str) -> str:
+        return await self._client.encrypter.index(value)
+
     async def decrypt(self, *args: Any, **kwargs: Any) -> Any:
         return await self._client.decrypt(*args, **kwargs)
 
